finchan.dispatcher
======================

.. automodule:: finchan.dispatcher

   Dispatcher
   --------------------
   .. autoclass:: BaseDispatcher
       :members:

   BackTrackDispatcher
   --------------------
   .. autoclass:: BackTrackDispatcher
       :members:

   LiveDispatcher
   --------------------
   .. autoclass:: LiveDispatcher
       :members:
